'use strict';

var _deepEqual = require('../deepEqual');

var _deepEqual2 = _interopRequireDefault(_deepEqual);

var _immutable = require('immutable');

var _expectations = require('../expectations');

var _expectations2 = _interopRequireDefault(_expectations);

var _addExpectations = require('../../../__tests__/addExpectations');

var _addExpectations2 = _interopRequireDefault(_addExpectations);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('structure.immutable.deepEqual', function () {
  var expect = (0, _addExpectations2.default)(_expectations2.default);

  it('work with nested Immutable.Maps', function () {
    expect((0, _deepEqual2.default)((0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }), (0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }))).toBe(true);
    expect((0, _deepEqual2.default)((0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }), (0, _immutable.fromJS)({
      a: {
        b: {
          c: 42
        },
        d: 2,
        e: 3
      },
      f: 4
    }))).toBe(false);
  });

  it('work with plain objects', function () {
    expect((0, _deepEqual2.default)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }, {
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    })).toBe(true);
    expect((0, _deepEqual2.default)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }, {
      a: {
        b: {
          c: 42
        },
        d: 2,
        e: 3
      },
      f: 4
    })).toBe(false);
  });

  it('work with plain objects inside Immutable.Maps', function () {
    expect((0, _deepEqual2.default)((0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }).setIn('a.b.g', { h: { i: 29 } }), (0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }).setIn('a.b.g', { h: { i: 29 } }))).toBe(true);
    expect((0, _deepEqual2.default)((0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }).setIn('a.b.g', { h: { i: 29 } }), (0, _immutable.fromJS)({
      a: {
        b: {
          c: 1
        },
        d: 2,
        e: 3
      },
      f: 4
    }).setIn('a.b.g', { h: { i: 30 } }))).toBe(false);
  });

  it('work with Immutable.Maps inside plain objects', function () {
    expect((0, _deepEqual2.default)({
      a: {
        b: {
          c: (0, _immutable.fromJS)({
            h: {
              i: 29
            }
          })
        },
        d: 2,
        e: 3
      },
      f: 4
    }, {
      a: {
        b: {
          c: (0, _immutable.fromJS)({
            h: {
              i: 29
            }
          })
        },
        d: 2,
        e: 3
      },
      f: 4
    })).toBe(true);
    expect((0, _deepEqual2.default)({
      a: {
        b: {
          c: (0, _immutable.fromJS)({
            h: {
              i: 29
            }
          })
        },
        d: 2,
        e: 3
      },
      f: 4
    }, {
      a: {
        b: {
          c: (0, _immutable.fromJS)({
            h: {
              i: 30
            }
          })
        },
        d: 2,
        e: 3
      },
      f: 4
    })).toBe(false);
  });
});